<template>
	<NodeBasicLayout v-model:title="data.title" :type="NodeType.Analysis">
		<Handle :id="targetHandleId" type="target" :position="Position.Left" />
		<FieldLayout :title="modelSetting.name">
			<div class="w-[340px] flex-items-center gap-x-2">
				<div class="flex-column gap-y-1.5">
					<span class="text-gray-500">{{ VueFlowHelper.getParams(modelSetting, 'llm_model').label }}</span>

					<el-select
						v-model="VueFlowHelper.getParams(modelSetting, 'llm_model').value"
						class="w-[150px]"
						:placeholder="VueFlowHelper.getParams(modelSetting, 'llm_model').placeholder"
					>
						<el-option v-for="item in VueFlowConstant.LLM_MODEL_LIST" :key="item.value" :label="item.label" :value="item.value" />
					</el-select>
				</div>
				<div class="flex-column gap-y-1.5">
					<span class="text-gray-500">{{ VueFlowHelper.getParams(modelSetting, 'temperature').label }}</span>
					<el-input-number
						v-model="VueFlowHelper.getParams(modelSetting, 'temperature').value"
						class="w-[180px]"
						placeholder=""
					></el-input-number>
				</div>
			</div>
		</FieldLayout>
		<FieldLayout :title="prompt.name">
			<el-input
				class="nowheel"
				v-model="VueFlowHelper.getParams(prompt, 'prompt').value"
				type="textarea"
				:autosize="{ minRows: 3, maxRows: 6 }"
				autocomplete="off"
			>
			</el-input>
		</FieldLayout>
		<Handle :id="sourceHandleId" type="source" :position="Position.Right" />
	</NodeBasicLayout>
</template>

<script lang="ts" setup>
import { Handle, Position, useNode, useVueFlow } from '@vue-flow/core';
import { ref } from 'vue';

import type { NodeProps } from '@vue-flow/core';
import { VueFlowConstant } from '../../VueFlowConstant';
import { VueFlowHelper } from '../../VueFlowHelper';
import type { LLMNodeData, LLMNodeEvents } from './index';
import { deepClone } from '/@/utils/other';
import { NodeType } from '../../vueFlowEnum';

import FieldLayout from './components/FieldLayout.vue';
import NodeBasicLayout from './components/NodeBasicLayout.vue';

defineProps<NodeProps<LLMNodeData, LLMNodeEvents>>();

const node = useNode();
const sourceHandleId = ref(VueFlowHelper.getHandleId(node.node, 'source'));
const targetHandleId = ref(VueFlowHelper.getHandleId(node.node, 'target'));

const data = ref(node.node.data);

const modelSetting = ref(VueFlowHelper.getGroupParam(data.value, 0));
const prompt = ref(VueFlowHelper.getGroupParam(data.value, 1));

VueFlowHelper.getConfigValue(VueFlowHelper.getParams(prompt.value, 'prompt'), 'label', '');
</script>
